=======
Startup
=======

SWAN startup commands

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.components.startup.PROJECT
   rompy_swan.components.startup.SET
   rompy_swan.components.startup.MODE
   rompy_swan.components.startup.COORDINATES

